=============
Symbol Please
=============


.. image:: https://img.shields.io/pypi/v/symbol_please.svg
        :target: https://pypi.python.org/pypi/symbol_please


Symbol Please is a visual log parsing helper for Project 1999


Dependencies
------------

* GTK+3

Features
--------

* Built-in buff timers

Changelog
---------

1.0.0 (June 13, 2019)
~~~~~~~~~~~~~~~~~~~~~
- Initial release.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
